==> ismah-3.0.2%2B1.19.4%2Bforge-sources.jar: com/github/razorplay01/ismah/client/util/LeashRenderer.java <==
package com.github.razorplay01.ismah.client.util;

import com.github.razorplay01.ismah.common.mixin.PlayerModelAccessor;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.model.geom.ModelPart;
import net.minecraft.client.model.geom.PartPose;
import net.minecraft.client.model.geom.builders.*;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.RenderType;
import net.minecraft.client.renderer.texture.OverlayTexture;
import net.minecraft.resources.ResourceLocation;

public class LeashRenderer {
    private LeashRenderer() {
        // []
    }
    private static final ResourceLocation TEXTURE = /*? >=1.21 {*/ /*ResourceLocation.parse *//*?} else {*/ new ResourceLocation /*?}*/("textures/entity/lead_knot.png");

    private static final ModelPart RIGHT_LEASH = buildModel(
            "leads$right_leash",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(1.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static final ModelPart RIGHT_LEASH_SLIM = buildModel(
            "leads$right_leash_slim",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(2.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static final ModelPart LEFT_LEASH = buildModel(
            "leads$left_leash",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(3.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static final ModelPart LEFT_LEASH_SLIM = buildModel(
            "leads$left_leash",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(3.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static ModelPart buildModel(String name, CubeListBuilder builder) {
        MeshDefinition modelData = new MeshDefinition();
        PartDefinition modelPartData = modelData.m_171576_();
        modelPartData.m_171599_(name, builder, PartPose.m_171419_(-5.0F, 2.0F, 0.0F));
        return LayerDefinition.m_171565_(modelData, 32, 32).m_171564_();
    }

    public static void renderRightArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                           //? if <=1.21.1 {
                                           net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                           /*?} else {*/
                                           /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                           *///?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? RIGHT_LEASH_SLIM : RIGHT_LEASH;
        renderArmLeash(matrices, vertices, light, model.f_102811_, leash);
    }

    public static void renderLeftArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                          //? if <=1.21.1 {
                                          net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                          /*?} else {*/
                                          /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                          *///?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? LEFT_LEASH_SLIM : LEFT_LEASH;
        renderArmLeash(matrices, vertices, light, model.f_102812_, leash);
    }

    public static void renderArmLeash(PoseStack matrices, MultiBufferSource vertices, int light, ModelPart arm, ModelPart leash) {
        leash.f_104200_ = arm.f_104200_;
        leash.f_104201_ = arm.f_104201_;
        leash.f_104202_ = arm.f_104202_;
        leash.f_104203_ = arm.f_104203_;
        leash.f_104204_ = arm.f_104204_;
        leash.f_104205_ = arm.f_104205_;
        leash.f_233553_ = arm.f_233553_;
        leash.f_233554_ = arm.f_233554_;
        leash.f_233555_ = arm.f_233555_;

        leash.m_104301_(matrices, vertices.m_6299_(RenderType.m_110446_(TEXTURE)), light, OverlayTexture.f_118083_);
    }
}

==> ismah-3.1.1%2B1.19.4%2Bforge-sources.jar: com/github/razorplay01/ismah/client/util/LeashRenderer.java <==
package com.github.razorplay01.ismah.client.util;

import com.github.razorplay01.ismah.common.mixin.PlayerModelAccessor;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.model.geom.ModelPart;
import net.minecraft.client.model.geom.PartPose;
import net.minecraft.client.model.geom.builders.*;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.RenderType;
import net.minecraft.client.renderer.texture.OverlayTexture;
import net.minecraft.resources.ResourceLocation;

public class LeashRenderer {
    private LeashRenderer() {
        // []
    }
    private static final ResourceLocation TEXTURE = /*? >=1.21 {*/ /*ResourceLocation.parse *//*?} else {*/ new ResourceLocation /*?}*/("textures/entity/lead_knot.png");

    public static final ModelPart RIGHT_LEASH = buildModel(
            "leads$right_leash",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(1.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static final ModelPart RIGHT_LEASH_SLIM = buildModel(
            "leads$right_leash_slim",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(2.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static final ModelPart LEFT_LEASH = buildModel(
            "leads$left_leash",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(3.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static final ModelPart LEFT_LEASH_SLIM = buildModel(
            "leads$left_leash",
            CubeListBuilder.m_171558_().m_171514_(0, 0).m_171488_(3.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static ModelPart buildModel(String name, CubeListBuilder builder) {
        MeshDefinition modelData = new MeshDefinition();
        PartDefinition modelPartData = modelData.m_171576_();
        modelPartData.m_171599_(name, builder, PartPose.m_171419_(-5.0F, 2.0F, 0.0F));
        return LayerDefinition.m_171565_(modelData, 32, 32).m_171564_();
    }

    public static void renderRightArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                           //? if <=1.21.1 {
                                           net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                           /*?} else {*/
                                           /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                           *///?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? RIGHT_LEASH_SLIM : RIGHT_LEASH;
        renderArmLeash(matrices, vertices, light, model.f_102811_, leash);
    }

    public static void renderLeftArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                          //? if <=1.21.1 {
                                          net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                          /*?} else {*/
                                          /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                          *///?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? LEFT_LEASH_SLIM : LEFT_LEASH;
        renderArmLeash(matrices, vertices, light, model.f_102812_, leash);
    }

    public static void renderArmLeash(PoseStack matrices, MultiBufferSource vertices, int light, ModelPart arm, ModelPart leash) {
        leash.f_104200_ = arm.f_104200_;
        leash.f_104201_ = arm.f_104201_;
        leash.f_104202_ = arm.f_104202_;
        leash.f_104203_ = arm.f_104203_;
        leash.f_104204_ = arm.f_104204_;
        leash.f_104205_ = arm.f_104205_;
        leash.f_233553_ = arm.f_233553_;
        leash.f_233554_ = arm.f_233554_;
        leash.f_233555_ = arm.f_233555_;

        leash.m_104301_(matrices, vertices.m_6299_(RenderType.m_110446_(TEXTURE)), light, OverlayTexture.f_118083_);
    }
}
